#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import os
from setuptools import setup
from setuptools.command.install import install
from subprocess import call

from boilerplate.configuration import *

class post_install(install):
    def run(self):
        install.run(self)
        self.post_install()
    def post_install(self):
        try:
            call(["glib-compile-schemas", "/usr/share/glib-2.0/schemas/"])
        except OSError as e:
            if e.errno == os.errno.ENOENT:
                print("The command \"glib-compile-schemas\" does not exists, please install it then run:\n$ glib-compile-schemas /usr/share/glib-2.0/schemas/")
            else:
                print("glib-compile-schemas failed for soom unknown reason, try running it in your shell:\n$ glib-compile-schemas /usr/share/glib-2.0/schemas/")

# OS specific settings
if "nt" == os.name:
    data_files = []
else:
    # Default install /usr/local/...
    data_files = [
        # Desktop, appdata, and gschema
        ("/usr/share/applications", ["data/tld.domain.boilerplate.desktop"]),
        ("/usr/share/appdata/", ["data/tld.domain.boilerplate.appdata.xml"]),
        ("/usr/share/glib-2.0/schemas/", ["data/tld.domain.boilerplate.gschema.xml"]),
        # Icons
        ("/usr/share/icons/hicolor/scalable/apps", ["data/icons/hicolor/scalable/apps/tld.domain.boilerplate.svg"]),
        ("/usr/share/icons/hicolor/symbolic/apps", ["data/icons/hicolor/symbolic/apps/tld.domain.boilerplate.svg"]),
        ("/usr/share/icons/hicolor/16x16/apps", ["data/icons/hicolor/16x16/apps/tld.domain.boilerplate.png"]),
        ("/usr/share/icons/hicolor/22x22/apps", ["data/icons/hicolor/22x22/apps/tld.domain.boilerplate.png"]),
        ("/usr/share/icons/hicolor/32x32/apps", ["data/icons/hicolor/32x32/apps/tld.domain.boilerplate.png"]),
        ("/usr/share/icons/hicolor/48x48/apps", ["data/icons/hicolor/48x48/apps/tld.domain.boilerplate.png"]),
        ("/usr/share/icons/hicolor/256x256/apps", ["data/icons/hicolor/256x256/apps/tld.domain.boilerplate.png"])
    ]

# Read README as long description if we can
if os.path.isfile("README"):
    with open("README") as readme:
        long_description = readme.read()
else:
    long_description = ""

# Setup
setup(
    name = "boilerplate",
    version = "0.1.0",
    description = "A boilerplate for a GTK3 application written in Python 3.",
    long_description = long_description,
    author = "Julian Richen",
    author_email = "julian@richen.io",
    url = "https://github.com/julianrichen/python3-gtk3-application-boilerplate",
    license = "GPLv3",
    packages = [
        "boilerplate"
    ],
    entry_points = {
        "console_scripts": [
            "boilerplate=boilerplate.application:main"
        ],
    },
    data_files = data_files,
    cmdclass = {
        #'develop': post_install_dev,
        'install': post_install,
    }
)
